sim_base: Simulated data (no interactive fixed effects)

sim_baseR Documentation

Simulated data (no interactive fixed effects)

Description

A simulated dataset with continuous outcomes and no interactive fixed effects (factor loadings set to zero). Same DGP as simdata but with the factor contribution removed from the outcome.

Format

dataframe

References

Liu, L., Wang, Y., and Xu, Y. (2022). A Practical Guide to Counterfactual Estimators for Causal Inference with Time-Series Cross-Sectional Data. American Journal of Political Science, 68(1), 160-176.


fect documentation built on April 30, 2026, 9:06 a.m.