| sim_base | R Documentation |
A simulated dataset with continuous outcomes and no interactive fixed effects (factor loadings set to zero). Same DGP as simdata but with the factor contribution removed from the outcome.
dataframe
Liu, L., Wang, Y., and Xu, Y. (2022). A Practical Guide to Counterfactual Estimators for Causal Inference with Time-Series Cross-Sectional Data. American Journal of Political Science, 68(1), 160-176.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.